import os
import re
import sys
import argparse

############################## INPUT PARAMETERS #############################

# Fill the name of the .vrscene product file. It should be in the base folder.
Product='Armchair_01.vrscene'

#############################################################################

basePath = os.path.dirname(os.path.abspath(__file__))
scenesPath = os.path.join(basePath, 'Scenes')
viewsPath = os.path.join(basePath, 'Views')

if not os.path.isdir(scenesPath):
    os.makedirs(scenesPath, 0o755)

argumentsParser = argparse.ArgumentParser()

argumentsParser.add_argument('--product', nargs='?', default=Product)
args = argumentsParser.parse_args()

Product = args.product

RENDER_VIEW_REGEX = r'RenderView\s+\w+\s+\{[^}]+\}'

# Get all RenderViews:
renderViewForCamera = {}
for viewName in os.listdir(viewsPath):
    cameraName = os.path.splitext(viewName)[0]
    fullPath = os.path.join(viewsPath, viewName)

    with open(fullPath, 'r') as view:
        renderView = re.search(RENDER_VIEW_REGEX, view.read(), re.MULTILINE)

        if renderView is not None:
            renderViewForCamera[cameraName] = renderView.group()
# Now we have the RenderView from each scene in Views/ stored in renderViewForCamera

baseProductName = os.path.splitext(Product)[0]
productScene = ''
with open(os.path.join(basePath, Product)) as productSceneFile:
    productScene = productSceneFile.read()

# Create a new scene from the product and each renderView, replacing
# the original RenderView of the product
for cameraName, renderView in renderViewForCamera.items():
    outputFileName = os.path.join(scenesPath, '{0}_{1}.vrscene'.format(baseProductName, cameraName))

    with open(outputFileName, 'w') as outputScene:
        outputScene.write(re.sub(RENDER_VIEW_REGEX, renderView, productScene, flags=re.MULTILINE))
        print(outputFileName + ' has been successfully created!')

print('''
_____________________________________________________________________________________

The new .vrscene files were saved in {scenesPath}

'Press "Enter" to continue.
'''.format(scenesPath=scenesPath))

wait=sys.stdin.readline()